#!/usr/bin/env python
"""
Integration tests for wrapper functionality in the dot submodule.

Public use of this module is not supported by NAG.
"""

# NAG Copyright 2019.

# pylint: disable=invalid-name

import unittest

from naginterfaces.library import dot as chapter
from test_functionality_core import IntegrationTest

class TestX03aa(IntegrationTest): # pylint: disable=too-few-public-methods
    """
    Abstract suite of integration tests for the x03aa wrapper.
    """

class TestX03aaBase(TestX03aa, unittest.TestCase):
    """
    Concrete level-2 tests.
    """

    def setUp(self):
        TestX03aa.set_up(self)
        self.fun = chapter.real_prec

    def test_good(self):
        """
        Good call.
        """
        self.assertEqual(
            self.fun([-3., -5., 1.], [8., -4., -2.], 1., 0., True),
            (-5., 0.),
        )

class TestX03ab(IntegrationTest): # pylint: disable=too-few-public-methods
    """
    Abstract suite of integration tests for the x03ab wrapper.
    """

class TestX03abBase(TestX03ab, unittest.TestCase):
    """
    Concrete level-2 tests.
    """

    def setUp(self):
        TestX03ab.set_up(self)
        self.fun = chapter.complex_prec

    def test_good(self):
        """
        Good call.
        """
        self.assertEqual(
            self.fun(
                [
                    -1.j,
                    1.j,
                    -1. -1.j,
                ],
                [
                    1.j,
                    1. - 1.j,
                    -1.j,
                ],
                1. + 1.j, True,
            ),
            2. + 3.j,
        )

if __name__ == '__main__': # pragma: no cover
    unittest.main()
